@@ -2,6 +2,7 @@
 """Code taken from: http://www.scipy.org/Cookbook/SavitzkyGolay"""
 import numpy as np
 
+
 def savitzky_golay(y, window_size, order, deriv=0):
     r"""Smooth (and optionally differentiate) data with a Savitzky-Golay filter.
     The Savitzky-Golay filter removes high frequency noise from data.
@@ -53,20 +54,24 @@ def savitzky_golay(y, window_size, order, deriv=0):
     try:
         window_size = np.abs(np.int(window_size))
         order = np.abs(np.int(order))
-    except ValueError, msg:
-        raise(ValueError("window_size and order have to be of type int"))
+    except ValueError:
+        raise ValueError("window_size and order have to be of type int")
     if window_size % 2 != 1 or window_size < 1:
-        raise(TypeError("window_size size must be a positive odd number"))
+        raise TypeError("window_size size must be a positive odd number")
     if window_size < order + 2:
-        raise(TypeError("window_size is too small for the polynomials order"))
-    order_range = range(order+1)
-    half_window = (window_size -1) // 2
+        raise TypeError("window_size is too small for the polynomials order")
+    order_range = list(range(order + 1))
+    half_window = (window_size - 1) // 2
     # precompute coefficients
-    b = np.mat([[k**i for i in order_range] for k in range(-half_window, half_window+1)])
+    b = np.mat(
+        [[k ** i for i in order_range] for k in range(-half_window, half_window + 1)]
+    )
     m = np.linalg.pinv(b).A[deriv]
     # pad the signal at the extremes with
     # values taken from the signal itself
-    firstvals = y[0] - np.abs( y[1:half_window+1][::-1] - y[0] )
-    lastvals = y[-1] + np.abs(y[-half_window-1:-1][::-1] - y[-1])
+    firstvals = y[0] - np.abs(y[1 : half_window + 1][::-1] - y[0])
+    lastvals = y[-1] + np.abs(y[-half_window - 1 : -1][::-1] - y[-1])
     y = np.concatenate((firstvals, y, lastvals))
-    return np.correlate( m, y, mode='valid') # DNM: I patched this from convolve to correlate, fixing the signs of odd-numbered derivatives...
+    return np.correlate(
+        m, y, mode="valid"
+    )  # DNM: I patched this from convolve to correlate, fixing the signs of odd-numbered derivatives...
